/// <reference types="node" />
import { Server as HttpServer } from 'http';
import { Server, Socket } from 'socket.io';
import { AccountProvider } from '../accounts/providers';
import { AccountStates } from '../accounts/state';
import { AmmanAccountProvider, AmmanAccountRendererMap } from '../types';
import { Account, Program } from '../validator/types';
/**
 * A simple socket.io server which communicates to the Amman Explorere as well as accepting connections
 * from other clients, i.e. via an {@link AmmanClient} which tests can use to communicate via the amman API.
 *
 * @private
 */
declare class RelayServer {
    readonly io: Server;
    readonly accountProvider: AccountProvider;
    readonly accountStates: AccountStates;
    private readonly allKnownLabels;
    constructor(io: Server, accountProvider: AccountProvider, accountStates: AccountStates, allKnownLabels?: Record<string, string>);
    hookConnectionEvents(): void;
    hookMessages(socket: Socket): void;
}
/**
 * Sets up the Amman Relay which uses the given account provider to resolve account data.
 * @private
 * */
export declare class Relay {
    private static createApp;
    static startServer(accountProviders: Record<string, AmmanAccountProvider>, accountRenderers: AmmanAccountRendererMap, programs: Program[], accounts: Account[], killRunning?: boolean): Promise<{
        app: HttpServer;
        io: Server;
        relayServer: RelayServer;
    }>;
}
export {};
